@@ -55,9 +55,8 @@ def map_json(mapping_config, json_data, strict=False):
                 list_result = []
                 list_json = walk_dict(json_data, key, strict)
                 for lj in list_json:
-                    list_result.append(
-                        lj[config]
-                    )
+                    if config in lj:
+                        list_result.append(lj[config])
                 result[prop] = list_result
             else:
                 result[config] = json_data[key] if strict else json_data.get(key)
